use crate::internal::modbus::tcp_code::ModbusTcpCode;
use serde::{Deserialize, Serialize};

pub mod pcs;

#[derive(Debug, Serialize, Deserialize)]
pub(crate) struct PcsCsvData {
    pub address: Option<u16>,
    pub code: Option<u8>,
    pub name: Option<String>,
    pub rw: Option<u8>,
    #[serde(rename = "type")]
    pub t: Option<String>,
    pub factor: Option<f32>,
    pub unit: Option<String>,
    pub note: Option<String>,
    pub desc: Option<String>,
}

/// pcs config
pub(crate) fn pcs_conf() -> anyhow::Result<Vec<ModbusTcpCode>> {
    let mut rdr = csv::Reader::from_path("config/pcs.csv")?;
    let mut vec = Vec::new();
    for result in rdr.deserialize() {
        let csv_data: PcsCsvData = result?;
        let code: ModbusTcpCode = csv_data.try_into()?;
        vec.push(code);
    }
    Ok(vec)
}

mod test {
    use crate::ems::pcs::pcs_conf;

    #[test]
    fn test_pcs_conf() {
        assert!(pcs_conf().is_ok());
    }
}
